; ===============================================================
; Set the variable name for the calculator binary 
; ===============================================================

.variablename "[%$PROJECT_BINARY$%]"

; ===============================================================
; Define shell and platform from environment variables
; (passed in by the various build scripts).
; ===============================================================

none		= 0	; No shell
ion		= 1	; Ion		83, 83+
mirageos	= 2	; MirageOS	83+
venus		= 3	; Venus		83

ti8x		= 1	; TI-83 Plus
ti83		= 2	; TI-83

shell		= [%SHELL%]
platform	= [%PLATFORM%]

; ===============================================================
; Set up the platform-specific settings: origins, include files,
; BCALL macros &c
; ===============================================================

.if platform == ti8x
	; TI-83 Plus
	.inclabels "ti83plus.lbl"
	.org $9D93
	.db $BB,$6D
	.define bcall(label) rst rBR_CALL \ .dw label
	.define	bcallz(label) jr nz,$+5 \ rst rBR_CALL \ .dw label
	.define	bcallnz(label) jr z,$+5 \ rst rBR_CALL \ .dw label
	.define	bcallc(label) jr nc,$+5 \ rst rBR_CALL \ .dw label
	.define	bcallnc(label) jr c,$+5	\ rst rBR_CALL \ .dw label
	.define bjump(label) call 50h \ .dw label	
	.define	bjumpz(label) jr nz,$+7 \ call 50h \ .dw label
	.define	bjumpnz(label) jr z,$+7 \ call 50h \ .dw label
	.define	bjumpc(label) jr nc,$+7 \ call 50h \ .dw label
	.define	bjumpnc(label) jr c,$+7	\ call 50h \ .dw label
	.binarymode TI8X
.elseif platform == ti83
	; TI-83
	.inclabels "ti83.lbl"
	.org shell == venus ? $9329 : $9327
	.define bcall(label) call label
	.define	bcallz(label) call z,label
	.define	bcallnz(label) call nz,label
	.define	bcallc(label) call c,label
	.define	bcallnc(label) call nc,label	
	.define bjump(label) jp label
	.binarymode TI83
.else
	; Invalid platform
	.fail "Invalid platform selection.\n"
	.end
.endif

; ===============================================================
; Program headers for Ion and MirageOS
; ===============================================================

.if shell == ion
	.if platform == ti8x
		.include "ion8x.inc"
	.else
		.include "ion83.inc"
	.endif
	ret
	jr nc, main
.elseif shell == mirageos
	.include "mirage.inc"
	ret
	.db 1
	.incbmp "resources/icon.gif", width = 15, height = 15
.elseif shell == venus
	.include "venus.inc"
	.db $E7,"9_[V?",0
	jr nc, main
.endif

; ===============================================================
; Set up TIOS ASCII-mapping
; ===============================================================

.asciimap '[', $C1

; ===============================================================
; Description field for shells supporting a description
; ===============================================================

.if shell != none
	.asc "[%$PROJECT_NAME$%]", 0
	.if shell == venus
		.incbmp "resources/icon.gif", width = 16, height = 16
	.endif
.endif

; ===============================================================
; Defines for code that requires them (backwards compatibility)
; ===============================================================

.if platform == ti8x
	.if shell == none
		.define TI83P
	.elseif shell == ion
		.define TI83PI
	.elseif shell == mirageos
		.define TI83PM
	.endif
.elseif platform == ti83
	.if shell == none
		.define TI83
	.elseif shell == ion
		.define TI83I
	.endif
.endif